@@ -1,7 +1,10 @@
+from collections import defaultdict
 from functools import wraps
 from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import signals as django_signals
+from django.db.models.signals import pre_init, post_init, post_save, pre_save, pre_delete, post_delete, post_migrate, \
+    pre_migrate
 from django.utils.timezone import now
 
 
@@ -243,3 +246,30 @@ class temporary_disconnect_signal:
                 dispatch_uid=self.dispatch_uid,
                 weak=False
             )
+
+
+class disable_signals:
+    def __init__(self, disabled_signals=None):
+        self.stashed_signals = defaultdict(list)
+        self.disabled_signals = disabled_signals or [
+            pre_init, post_init,
+            pre_save, post_save,
+            pre_delete, post_delete,
+            pre_migrate, post_migrate,
+        ]
+
+    def __enter__(self):
+        for signal in self.disabled_signals:
+            self.disconnect(signal)
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        for signal in list(self.stashed_signals):
+            self.reconnect(signal)
+
+    def disconnect(self, signal):
+        self.stashed_signals[signal] = signal.receivers
+        signal.receivers = []
+
+    def reconnect(self, signal):
+        signal.receivers = self.stashed_signals.get(signal, [])
+        del self.stashed_signals[signal]
