@@ -286,7 +286,7 @@ def qrcode(value, alt=None):
                              urllib.urlencode({'chs': '250x250', 'cht': 'qr', 'chl': value, 'choe': 'UTF-8'}))
     alt = conditional_escape(alt or value)
 
-    return mark_safe(u"""<img class="qrcode" src="%s" width="250" height="250" alt="%s" />""" % (url, alt))
+    return mark_safe("""<img class="qrcode" src="%s" width="250" height="250" alt="%s" />""" % (url, alt))
 
 
 @register.filter
@@ -299,9 +299,13 @@ def barcode(code, args=None):
         # return as HTML element
         return mark_safe('<img src="data:image/png;base64,' + barcode + '" />')
     except IllegalCharacterError as e:
-        message = unicode(e)
-        character = message.split(':', 1)[1]
-        return '{}: {}'.format(_('Invalid characters'), character)
+        message = str(e)
+
+        if ':' in message:
+            character = message.split(':', 1)[1]
+            return '{}: {}'.format(_('Invalid characters'), character)
+        else:
+            return message
 
 
 @register.inclusion_tag('helpers/pagination.html', takes_context=True)
@@ -390,7 +394,7 @@ def translate(text):
 @register.filter
 def filename(value):
     try:
-        return os.path.basename(unicode(value.file.name))
+        return os.path.basename(str(value.file.name))
     except:
         return value
 
@@ -658,3 +662,9 @@ def objects_stats(objects, count_attr, sum_attr=None):
 @register.filter
 def date_from_isoformat(date_string):
     return datetime.date.fromisoformat(date_string)
+
+
+@register.simple_tag()
+def values_list(qs, attrs):
+    attributes = attrs.split(',')
+    return qs.values_list(*attributes, flat=True)
